@@ -1,7 +1,7 @@
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
 %  Adapter file for ECLiPSe 6.1#143 and later versions
-%  Last updated on August 19, 2021
+%  Last updated on October 12, 2021
 %
 %  This file is part of Logtalk <https://logtalk.org/>
 %  Copyright 1998-2021 Paulo Moura <pmoura@logtalk.org>
@@ -151,6 +151,9 @@ forall(Generate, Test) :-
 	!,
 	functor(Predicate, Functor, Arity),
 	'$lgt_eclipse_module_predicate_property'(Module, Functor/Arity, Property).
+:- if((get_flag(version_as_list, Version), Version @> [7,0,24])).
+	'$lgt_predicate_property'(setup_call_cleanup(_, _, _), built_in).
+:- endif.
 '$lgt_predicate_property'(Predicate, Property) :-
 	!,
 	functor(Predicate, Functor, Arity),
@@ -246,6 +249,9 @@ forall(Generate, Test) :-
 '$lgt_prolog_meta_predicate'(make_suspension(_, _, _), make_suspension(0, *, *), predicate).
 '$lgt_prolog_meta_predicate'(mutex(_, _), mutex(*, 0), predicate).
 '$lgt_prolog_meta_predicate'(not(_), not(0), predicate).
+:- if((get_flag(version_as_list, Version), Version @> [7,0,24])).
+	'$lgt_prolog_meta_predicate'(setup_call_cleanup(_, _, _), setup_call_cleanup(0, 0, 0), predicate).
+:- endif.
 '$lgt_prolog_meta_predicate'(subcall(_, _), subcall(0, *), predicate).
 '$lgt_prolog_meta_predicate'(suspend(_, _, _), suspend(0, *, *), predicate).
 '$lgt_prolog_meta_predicate'(suspend(_, _, _, _), suspend(0, *, *, *), predicate).
@@ -555,6 +561,14 @@ forall(Generate, Test) :-
 	compile(Path, Options).
 
 
+% '$lgt_load_prolog_file'(+atom)
+%
+% compile and (re)load a Prolog file
+
+'$lgt_load_prolog_file'(File) :-
+	compile(File).
+
+
 % '$lgt_file_modification_time'(+atom, -nonvar)
 %
 % gets a file modification time, assumed to be an opaque term but comparable
@@ -589,6 +603,17 @@ forall(Generate, Test) :-
 	atom_string(Extension, ExtensionString).
 
 
+% '$lgt_directory_files'(+atom, -list(atom))
+%
+% returns a list of files in the given directory
+
+'$lgt_directory_files'(Directory, Files) :-
+   	read_directory(Directory, '*', Directories0, Files0),
+   	findall(File1, (member(File0, Files0), atom_string(File1, File0)), Files1),
+   	findall(Directory1, (member(Directory0, Directories0), atom_string(Directory1, Directory0)), Directories1),
+   	append(['.', '..'| Directories1], Files1, Files).
+
+
 
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
@@ -885,6 +910,96 @@ forall(Generate, Test) :-
 
 
 
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%
+%  atomics concat (not currently used in the compiler/runtime)
+%
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+
+
+% atomic_concat(+atomic, +atomic, ?atom)
+
+:- if(\+ predicate_property(atomic_concat(_, _, _), built_in)).
+
+	atomic_concat(Atomic1, Atomic2, Atom) :-
+		(	var(Atomic1) ->
+			throw(error(instantiation_error, atomic_concat/3))
+		;	var(Atomic2) ->
+			throw(error(instantiation_error, atomic_concat/3))
+		;	\+ atomic(Atomic1) ->
+			throw(error(type_error(atomic, Atomic1), atomic_concat/3))
+		;	\+ atomic(Atomic2) ->
+			throw(error(type_error(atomic, Atomic2), atomic_concat/3))
+		;	'$lgt_gnu_atomic_atom'(Atomic1, Atom1),
+			'$lgt_gnu_atomic_atom'(Atomic2, Atom2),
+			atom_concat(Atom1, Atom2, Atom)
+		).
+
+	'$lgt_gnu_atomic_atom'(Atomic, Atom) :-
+		(	atom(Atomic) ->
+			Atom = Atomic
+		;	number_codes(Atomic, Codes),
+			atom_codes(Atom, Codes)
+		).
+
+:- endif.
+
+
+% atomic_list_concat(@list(atomic), ?atom)
+
+:- if(\+ predicate_property(atomic_list_concat(_, _), built_in)).
+
+	atomic_list_concat([Atomic| Atomics], Atom) :-
+		!,
+		(	var(Atomic) ->
+			throw(error(instantiation_error, atomic_list_concat/2))
+		;	\+ atomic(Atomic) ->
+			throw(error(type_error(atomic, Atomic), atomic_list_concat/2))
+		;	'$lgt_gnu_atomic_atom'(Atomic, Atom0),
+			'$lgt_gnu_atomic_list_concat'(Atomics, Atom0, Atom)
+		).
+	atomic_list_concat([], '').
+
+	'$lgt_gnu_atomic_list_concat'([Next| Atomics], Atom0, Atom) :-
+		!,
+		atomic_list_concat([Next| Atomics], Atom1),
+		atom_concat(Atom0, Atom1, Atom).
+	'$lgt_gnu_atomic_list_concat'([], Atom, Atom).
+
+:- endif.
+
+
+% atomic_list_concat(@list(atomic), +atom, ?atom)
+
+:- if(\+ predicate_property(atomic_list_concat(_, _, _), built_in)).
+
+	atomic_list_concat([Atomic| Atomics], Separator, Atom) :-
+		!,
+		(	var(Atomic) ->
+			throw(error(instantiation_error, atomic_list_concat/3))
+		;	var(Separator) ->
+			throw(error(instantiation_error, atomic_list_concat/3))
+		;	\+ atomic(Atomic) ->
+			throw(error(type_error(atomic, Atomic), atomic_list_concat/3))
+		;	\+ atomic(Separator) ->
+			throw(error(type_error(atomic, Separator), atomic_list_concat/3))
+		;	'$lgt_gnu_atomic_atom'(Atomic, Atom0),
+			'$lgt_gnu_atomic_atom'(Separator, SeparatorAtom),
+			'$lgt_gnu_atomic_list_concat'(Atomics, Atom0, SeparatorAtom, Atom)
+		).
+	atomic_list_concat([], _, '').
+
+	'$lgt_gnu_atomic_list_concat'([Next| Atomics], Atom0, SeparatorAtom, Atom) :-
+		!,
+		atomic_list_concat([Next| Atomics], SeparatorAtom, Atom2),
+		atom_concat(SeparatorAtom, Atom2, Atom1),
+		atom_concat(Atom0, Atom1, Atom).
+	'$lgt_gnu_atomic_list_concat'([], Atom, _, Atom).
+
+:- endif.
+
+
+
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
 %  string built-in type
