@@ -1,7 +1,7 @@
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
 %  Adapter file for ProscriptLS 1.5.9 and later versions
-%  Last updated on July 14, 2021
+%  Last updated on October 25, 2021
 %
 %  This file is part of Logtalk <https://logtalk.org/>
 %  Copyright 1998-2021 Paulo Moura <pmoura@logtalk.org>
@@ -137,6 +137,7 @@
 
 '$lgt_prolog_meta_predicate'(call_cleanup(_, _), call_cleanup(0, 0), predicate).
 '$lgt_prolog_meta_predicate'(setup_call_cleanup(_, _, _), setup_call_cleanup(0, 0, 0), predicate).
+'$lgt_prolog_meta_predicate'(setup_call_catcher_cleanup(_, _, _, _), setup_call_catcher_cleanup(0, 0, *, 0), predicate).
 
 
 % '$lgt_prolog_meta_directive'(@callable, -callable)
@@ -391,6 +392,14 @@
 	consult(File).
 
 
+% '$lgt_load_prolog_file'(+atom)
+%
+% compile and (re)load a Prolog file
+
+'$lgt_load_prolog_file'(File) :-
+	consult(File).
+
+
 % '$lgt_file_modification_time'(+atom, -nonvar)
 %
 % gets a file modification time, assumed to be an opaque term but comparable
@@ -447,6 +456,14 @@
 	).
 
 
+% '$lgt_directory_files'(+atom, -list(atom))
+%
+% returns a list of files in the given directory
+
+'$lgt_directory_files'(Directory, Files) :-
+	?????.
+
+
 
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
@@ -602,6 +619,84 @@ term_hash(_, _, _, _) :-
 
 
 
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%
+%  atomics concat (not currently used in the compiler/runtime)
+%
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+
+
+% atomic_concat(+atomic, +atomic, ?atom)
+
+atomic_concat(Atomic1, Atomic2, Atom) :-
+	(	var(Atomic1) ->
+		throw(error(instantiation_error, atomic_concat/3))
+	;	var(Atomic2) ->
+		throw(error(instantiation_error, atomic_concat/3))
+	;	\+ atomic(Atomic1) ->
+		throw(error(type_error(atomic, Atomic1), atomic_concat/3))
+	;	\+ atomic(Atomic2) ->
+		throw(error(type_error(atomic, Atomic2), atomic_concat/3))
+	;	'$lgt_proscriptls_atomic_atom'(Atomic1, Atom1),
+		'$lgt_proscriptls_atomic_atom'(Atomic2, Atom2),
+		atom_concat(Atom1, Atom2, Atom)
+	).
+
+'$lgt_proscriptls_atomic_atom'(Atomic, Atom) :-
+	(	atom(Atomic) ->
+		Atom = Atomic
+	;	number_chars(Atomic, Chars),
+		atom_chars(Atom, Chars)
+	).
+
+
+% atomic_list_concat(@list(atomic), ?atom)
+
+atomic_list_concat([Atomic| Atomics], Atom) :-
+	!,
+	(	var(Atomic) ->
+		throw(error(instantiation_error, atomic_list_concat/2))
+	;	\+ atomic(Atomic) ->
+		throw(error(type_error(atomic, Atomic), atomic_list_concat/2))
+	;	'$lgt_proscriptls_atomic_atom'(Atomic, Atom0),
+		'$lgt_proscriptls_atomic_list_concat'(Atomics, Atom0, Atom)
+	).
+atomic_list_concat([], '').
+
+'$lgt_proscriptls_atomic_list_concat'([Next| Atomics], Atom0, Atom) :-
+	!,
+	atomic_list_concat([Next| Atomics], Atom1),
+	atom_concat(Atom0, Atom1, Atom).
+'$lgt_proscriptls_atomic_list_concat'([], Atom, Atom).
+
+
+% atomic_list_concat(@list(atomic), +atom, ?atom)
+
+atomic_list_concat([Atomic| Atomics], Separator, Atom) :-
+	!,
+	(	var(Atomic) ->
+		throw(error(instantiation_error, atomic_list_concat/3))
+	;	var(Separator) ->
+		throw(error(instantiation_error, atomic_list_concat/3))
+	;	\+ atomic(Atomic) ->
+		throw(error(type_error(atomic, Atomic), atomic_list_concat/3))
+	;	\+ atomic(Separator) ->
+		throw(error(type_error(atomic, Separator), atomic_list_concat/3))
+	;	'$lgt_proscriptls_atomic_atom'(Atomic, Atom0),
+		'$lgt_proscriptls_atomic_atom'(Separator, SeparatorAtom),
+		'$lgt_proscriptls_atomic_list_concat'(Atomics, Atom0, SeparatorAtom, Atom)
+	).
+atomic_list_concat([], _, '').
+
+'$lgt_proscriptls_atomic_list_concat'([Next| Atomics], Atom0, SeparatorAtom, Atom) :-
+	!,
+	atomic_list_concat([Next| Atomics], SeparatorAtom, Atom2),
+	atom_concat(SeparatorAtom, Atom2, Atom1),
+	atom_concat(Atom0, Atom1, Atom).
+'$lgt_proscriptls_atomic_list_concat'([], Atom, _, Atom).
+
+
+
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
 %  string built-in type
