@@ -1,7 +1,7 @@
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
 %  Adapter file for YAP Prolog 6.3.4 and later versions
-%  Last updated on October 12, 2021
+%  Last updated on November 23, 2021
 %
 %  This file is part of Logtalk <https://logtalk.org/>
 %  Copyright 1998-2021 Paulo Moura <pmoura@logtalk.org>
@@ -538,7 +538,7 @@
 % compile and (re)load a Prolog file
 
 '$lgt_load_prolog_file'(File) :-
-	load_files(File).
+	load_files(File, []).
 
 
 % '$lgt_file_modification_time'(+atom, -nonvar)
