@@ -1,7 +1,7 @@
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
 %  Default library paths
-%  Last updated on October 15, 2021
+%  Last updated on November 17, 2021
 %
 %  This file is part of Logtalk <https://logtalk.org/>
 %  Copyright 1998-2021 Paulo Moura <pmoura@logtalk.org>
@@ -111,10 +111,12 @@ logtalk_library_path(csv, library('csv/')).
 logtalk_library_path(dates, library('dates/')).
 logtalk_library_path(dependents, library('dependents/')).
 logtalk_library_path(dictionaries, library('dictionaries/')).
+logtalk_library_path(dif, library('dif/')).
 logtalk_library_path(edcg, library('edcg/')).
 logtalk_library_path(events, library('events/')).
 logtalk_library_path(expand_library_alias_paths, library('expand_library_alias_paths/')).
 logtalk_library_path(expecteds, library('expecteds/')).
+logtalk_library_path(format, library('format/')).
 logtalk_library_path(gensym, library('gensym/')).
 logtalk_library_path(git, library('git/')).
 logtalk_library_path(heaps, library('heaps/')).
@@ -310,13 +312,14 @@ logtalk_library_path(xpce, examples('xpce/')).
 logtalk_library_path(yield, engines('yield/')).
 
 % packs
-logtalk_library_path(logtalk_packs, LogtalkPacks) :-
-	(	'$lgt_environment_variable'('LOGTALKPACKS', _) ->
-		LogtalkPacks = '$LOGTALKPACKS/'
-	;	LogtalkPacks = home('logtalk_packs/')
-	).
-logtalk_library_path(Pack, logtalk_packs(Path)) :-
-	(	'$lgt_environment_variable'('LOGTALKPACKS', _) ->
+logtalk_library_path(Pack, PackPath) :-
+	(	var(Pack) ->
+		true
+	;	Pack \== logtalk_packs
+	),
+	(	'$lgt_expand_library_alias'(logtalk_packs, LogtalkPacks) ->
+		atom_concat(LogtalkPacks, '/packs', PathsPacks)
+	;	'$lgt_environment_variable'('LOGTALKPACKS', _) ->
 		PathsPacks = '$LOGTALKPACKS/packs'
 	;	'$lgt_environment_variable'('HOME', _) ->
 		PathsPacks = '$HOME/logtalk_packs/packs'
@@ -332,8 +335,5 @@ logtalk_library_path(Pack, logtalk_packs(Path)) :-
 		\+ sub_atom(Pack, 0, _, _, '.')
 	;	true
 	),
-	atom_concat(ExpandedPath, '/', PackPath0),
-	atom_concat(PackPath0, Pack, PackPath),
-	'$lgt_directory_exists'(PackPath),
-	atom_concat('packs/', Pack, Path0),
-	atom_concat(Path0, '/', Path).
+	atomic_list_concat([ExpandedPath, '/', Pack, '/'], PackPath),
+	'$lgt_directory_exists'(PackPath).
