@@ -5,7 +5,7 @@
 ##   Logtalk script for updating the HTML core, library, tools, ports, and
 ##   contributions documentation
 ## 
-##   Last updated on October 18, 2021
+##   Last updated on October 28, 2021
 ## 
 ##   This file is part of Logtalk <https://logtalk.org/>  
 ##   Copyright 1998-2021 Paulo Moura <pmoura@logtalk.org>
@@ -55,7 +55,7 @@ else
 fi
 
 print_version() {
-	echo "$(basename "$0") 0.17"
+	echo "$(basename "$0") 0.18"
 	exit 0
 }
 
@@ -108,12 +108,27 @@ elif [ "$p_arg" == "gnu" ] ; then
 elif [ "$p_arg" == "ji" ] ; then
 	prolog='JIProlog'
 	logtalk="jiplgt$extension -n -g"
+elif [ "$p_arg" == "lvm" ] ; then
+	prolog='LVM'
+	logtalk="lvmlgt$extension $i_arg -g"
+elif [ "$p_arg" == "scryer" ] ; then
+	prolog='Scryer Prolog'
+	logtalk="scryerlgt$extension $i_arg -g"
 elif [ "$p_arg" == "sicstus" ] ; then
 	prolog='SICStus Prolog'
 	logtalk="sicstuslgt$extension --goal"
 elif [ "$p_arg" == "swi" ] ; then
 	prolog='SWI-Prolog'
 	logtalk="swilgt$extension -g"
+elif [ "$p_arg" == "swipack" ] ; then
+	prolog='SWI-Prolog'
+	logtalk="swipl $i_arg -g"
+elif [ "$p_arg" == "tau" ] ; then
+	prolog='Tau Prolog'
+	logtalk="taulgt$extension $i_arg -g"
+elif [ "$p_arg" == "trealla" ] ; then
+	prolog='Trealla Prolog'
+	logtalk="tplgt$extension $i_arg -g"
 elif [ "$p_arg" == "xsb" ] ; then
 	prolog='XSB'
 	logtalk="xsblgt$extension -e"
