@@ -2,7 +2,7 @@
 //
 //   XML documenting files to reStructuredText files conversion script
 //
-//   Last updated on February 26, 2019
+//   Last updated on July 30, 2021
 //
 //   This file is part of Logtalk <https://logtalk.org/>  
 //   Copyright 1998-2021 Paulo Moura <pmoura@logtalk.org>
@@ -33,6 +33,7 @@ var WshShell = new ActiveXObject("WScript.Shell");
 var directory = WshShell.CurrentDirectory;
 
 var sphinx = false;
+var make_html = false;
 
 var index_file = "index.rst"
 var index_title = "Documentation index"
@@ -41,6 +42,7 @@ var processor = "msxsl";
 // var processor = "xsltproc";
 // var processor = "xalan";
 // var processor = "sabcmd";
+// var processor = "saxon";
 
 if (WScript.Arguments.Unnamed.Length > 0) {
 	usage_help();
@@ -96,6 +98,9 @@ if (WScript.Arguments.Named.Exists("p"))
 if (WScript.Arguments.Named.Exists("s"))
 	sphinx = true;
 
+if (WScript.Arguments.Named.Exists("m"))
+	make_html = true;
+
 var FSObject = new ActiveXObject("Scripting.FileSystemObject");
 
 if (d_arg != "" && !FSObject.FolderExists(d_arg)) {
@@ -111,7 +116,7 @@ if (i_arg != "")
 if (t_arg != "")
 	index_title=t_arg;
 
-if (p_arg != "" && p_arg != "msxsl" && p_arg != "xsltproc" && p_arg != "xalan" && p_arg != "sabcmd") {
+if (p_arg != "" && p_arg != "msxsl" && p_arg != "xsltproc" && p_arg != "xalan" && p_arg != "sabcmd" && p_arg != "saxon") {
 	WScript.Echo("Error! Unsupported XSLT processor:" + p_arg);
 	WScript.Echo("");
 	usage_help();
@@ -171,6 +176,9 @@ for (files.moveFirst(); !files.atEnd(); files.moveNext()) {
 			case "sabcmd" :
 				WshShell.Run("sabcmd \"" + xslt + "\" \"" + file + "\" \"" + rst_file + "\"", true);
 				break;
+			case "saxon" :
+				WshShell.Run("java net.sf.saxon.Transform -o:\"" + rst_file + "\" -s:\"" + file + "\" -xsl:\"" + xslt + "\"", true);
+				break;
 		}
 	}
 }
@@ -194,9 +202,18 @@ if (sphinx) {
 	FSObject.DeleteFile(WshShell.CurrentDirectory + "\\index.rst");
 	FSObject.MoveFile(WshShell.CurrentDirectory + "\\index.backup", WshShell.CurrentDirectory + "\\index.rst");
 	WScript.Echo("");
-	WScript.Echo("all done");
 }
 
+if (sphinx && make_html) {
+	WScript.Echo("");
+	WScript.Echo("running make html ...");
+	WScript.Echo("");
+	WshShell.Run("make html", 1, true);
+	WScript.Echo("");
+	
+}
+
+WScript.Echo("all done");
 WScript.Quit(0);
 
 function usage_help() {
@@ -205,15 +222,16 @@ function usage_help() {
 	WScript.Echo("current directory to reStructuredText files for use with Sphinx");
 	WScript.Echo("");
 	WScript.Echo("Usage:");
-	WScript.Echo("  " + WScript.ScriptName + " [/d:directory] [/i:index] [/t:title] [/p:processor] [/s]");
+	WScript.Echo("  " + WScript.ScriptName + " [/d:directory] [/i:index] [/t:title] [/p:processor] [/s] [/m]");
 	WScript.Echo("  " + WScript.ScriptName + " help");
 	WScript.Echo("");
 	WScript.Echo("Optional arguments:");
 	WScript.Echo("  d - output directory for the generated files (default is " + directory + ")");
 	WScript.Echo("  i - name of the index file (default is " + index_file + ")");
 	WScript.Echo("  t - title to be used in the index file (default is " + index_title + ")");
-	WScript.Echo("  p - XSLT processor (msxsl, xsltproc, xalan, or sabcmd; default is " + processor + ")");
+	WScript.Echo("  p - XSLT processor (msxsl, xsltproc, xalan, sabcmd, or saxon; default is " + processor + ")");
 	WScript.Echo("  s - run sphinx-quickstart script");
+	WScript.Echo("  m - run make html (requires also using the -s option)");
 	WScript.Echo("");
 	WScript.Quit(1);
 }
